==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/bs.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "bs",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan"
    ],
    "february": [
        "februar",
        "feb"
    ],
    "march": [
        "mart",
        "mar"
    ],
    "april": [
        "april",
        "apr"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "juni",
        "jun"
    ],
    "july": [
        "juli",
        "jul"
    ],
    "august": [
        "avgust",
        "avg"
    ],
    "september": [
        "septembar",
        "sep"
    ],
    "october": [
        "oktobar",
        "okt"
    ],
    "november": [
        "novembar",
        "nov"
    ],
    "december": [
        "decembar",
        "dec"
    ],
    "monday": [
        "ponedjeljak",
        "pon"
    ],
    "tuesday": [
        "utorak",
        "uto"
    ],
    "wednesday": [
        "srijeda",
        "sri"
    ],
    "thursday": [
        "četvrtak",
        "čet"
    ],
    "friday": [
        "petak",
        "pet"
    ],
    "saturday": [
        "subota",
        "sub"
    ],
    "sunday": [
        "nedjelja",
        "ned"
    ],
    "am": [
        "prijepodne"
    ],
    "pm": [
        "popodne"
    ],
    "year": [
        "godina",
        "god",
        "g"
    ],
    "month": [
        "mjesec",
        "mj"
    ],
    "week": [
        "sedmica",
        "sed"
    ],
    "day": [
        "dan"
    ],
    "hour": [
        "sat",
        "h"
    ],
    "minute": [
        "minuta",
        "min"
    ],
    "second": [
        "sekunda",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "prošle godine"
        ],
        "0 year ago": [
            "ove godine"
        ],
        "in 1 year": [
            "sljedeće godine"
        ],
        "1 month ago": [
            "prošli mjesec"
        ],
        "0 month ago": [
            "ovaj mjesec"
        ],
        "in 1 month": [
            "sljedeći mjesec"
        ],
        "1 week ago": [
            "prošle sedmice"
        ],
        "0 week ago": [
            "ove sedmice"
        ],
        "in 1 week": [
            "sljedeće sedmice"
        ],
        "1 day ago": [
            "jučer"
        ],
        "0 day ago": [
            "danas"
        ],
        "in 1 day": [
            "sutra"
        ],
        "0 hour ago": [
            "ovaj sat"
        ],
        "0 minute ago": [
            "ova minuta"
        ],
        "0 second ago": [
            "sada"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) godinu",
            "za (\\d+) godina",
            "za (\\d+) god",
            "za (\\d+) g"
        ],
        "\\1 year ago": [
            "prije (\\d+) godinu",
            "prije (\\d+) godina",
            "prije (\\d+) god",
            "prije (\\d+) g"
        ],
        "in \\1 month": [
            "za (\\d+) mjesec",
            "za (\\d+) mjeseci",
            "za (\\d+) mj"
        ],
        "\\1 month ago": [
            "prije (\\d+) mjesec",
            "prije (\\d+) mjeseci",
            "prije (\\d+) mj"
        ],
        "in \\1 week": [
            "za (\\d+) sedmicu",
            "za (\\d+) sedmica",
            "za (\\d+) sed"
        ],
        "\\1 week ago": [
            "prije (\\d+) sedmicu",
            "prije (\\d+) sedmica",
            "prije (\\d+) sed"
        ],
        "in \\1 day": [
            "za (\\d+) dan",
            "za (\\d+) dana",
            "za (\\d+) d"
        ],
        "\\1 day ago": [
            "prije (\\d+) dan",
            "prije (\\d+) dana",
            "prije (\\d+) d"
        ],
        "in \\1 hour": [
            "za (\\d+) sat",
            "za (\\d+) sati"
        ],
        "\\1 hour ago": [
            "prije (\\d+) sat",
            "prije (\\d+) sati"
        ],
        "in \\1 minute": [
            "za (\\d+) minutu",
            "za (\\d+) minuta",
            "za (\\d+) min"
        ],
        "\\1 minute ago": [
            "prije (\\d+) minutu",
            "prije (\\d+) minuta",
            "prije (\\d+) min"
        ],
        "in \\1 second": [
            "za (\\d+) sekundu",
            "za (\\d+) sekundi",
            "za (\\d+) sek"
        ],
        "\\1 second ago": [
            "prije (\\d+) sekundu",
            "prije (\\d+) sekundi",
            "prije (\\d+) sek"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/bs.py <==
info = {
    "name": "bs",
    "date_order": "DMY",
    "january": [
        "jan",
        "januar"
    ],
    "february": [
        "feb",
        "februar"
    ],
    "march": [
        "mar",
        "mart"
    ],
    "april": [
        "apr",
        "april"
    ],
    "may": [
        "maj"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "jul",
        "juli"
    ],
    "august": [
        "avg",
        "avgust"
    ],
    "september": [
        "sep",
        "septembar"
    ],
    "october": [
        "okt",
        "oktobar"
    ],
    "november": [
        "nov",
        "novembar"
    ],
    "december": [
        "dec",
        "decembar"
    ],
    "monday": [
        "pon",
        "ponedjeljak"
    ],
    "tuesday": [
        "uto",
        "utorak"
    ],
    "wednesday": [
        "sri",
        "srijeda"
    ],
    "thursday": [
        "čet",
        "četvrtak"
    ],
    "friday": [
        "pet",
        "petak"
    ],
    "saturday": [
        "sub",
        "subota"
    ],
    "sunday": [
        "ned",
        "nedjelja"
    ],
    "am": [
        "prijepodne"
    ],
    "pm": [
        "popodne"
    ],
    "year": [
        "g",
        "god",
        "godina"
    ],
    "month": [
        "mj",
        "mjesec"
    ],
    "week": [
        "sed",
        "sedmica"
    ],
    "day": [
        "dan"
    ],
    "hour": [
        "h",
        "sat"
    ],
    "minute": [
        "min",
        "minuta"
    ],
    "second": [
        "s",
        "sek",
        "sekunda"
    ],
    "relative-type": {
        "0 day ago": [
            "danas"
        ],
        "0 hour ago": [
            "ovaj sat"
        ],
        "0 minute ago": [
            "ova minuta"
        ],
        "0 month ago": [
            "ovaj mjesec"
        ],
        "0 second ago": [
            "sada"
        ],
        "0 week ago": [
            "ove sedmice"
        ],
        "0 year ago": [
            "ove godine"
        ],
        "1 day ago": [
            "jučer"
        ],
        "1 month ago": [
            "prošli mjesec"
        ],
        "1 week ago": [
            "prošle sedmice"
        ],
        "1 year ago": [
            "prošle godine"
        ],
        "in 1 day": [
            "sutra"
        ],
        "in 1 month": [
            "sljedeći mjesec"
        ],
        "in 1 week": [
            "sljedeće sedmice"
        ],
        "in 1 year": [
            "sljedeće godine"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "prije (\\d+) d",
            "prije (\\d+) dan",
            "prije (\\d+) dana"
        ],
        "\\1 hour ago": [
            "prije (\\d+) sat",
            "prije (\\d+) sati"
        ],
        "\\1 minute ago": [
            "prije (\\d+) min",
            "prije (\\d+) minuta",
            "prije (\\d+) minutu"
        ],
        "\\1 month ago": [
            "prije (\\d+) mj",
            "prije (\\d+) mjesec",
            "prije (\\d+) mjeseci"
        ],
        "\\1 second ago": [
            "prije (\\d+) sek",
            "prije (\\d+) sekundi",
            "prije (\\d+) sekundu"
        ],
        "\\1 week ago": [
            "prije (\\d+) sed",
            "prije (\\d+) sedmica",
            "prije (\\d+) sedmicu"
        ],
        "\\1 year ago": [
            "prije (\\d+) g",
            "prije (\\d+) god",
            "prije (\\d+) godina",
            "prije (\\d+) godinu"
        ],
        "in \\1 day": [
            "za (\\d+) d",
            "za (\\d+) dan",
            "za (\\d+) dana"
        ],
        "in \\1 hour": [
            "za (\\d+) sat",
            "za (\\d+) sati"
        ],
        "in \\1 minute": [
            "za (\\d+) min",
            "za (\\d+) minuta",
            "za (\\d+) minutu"
        ],
        "in \\1 month": [
            "za (\\d+) mj",
            "za (\\d+) mjesec",
            "za (\\d+) mjeseci"
        ],
        "in \\1 second": [
            "za (\\d+) sek",
            "za (\\d+) sekundi",
            "za (\\d+) sekundu"
        ],
        "in \\1 week": [
            "za (\\d+) sed",
            "za (\\d+) sedmica",
            "za (\\d+) sedmicu"
        ],
        "in \\1 year": [
            "za (\\d+) g",
            "za (\\d+) god",
            "za (\\d+) godina",
            "za (\\d+) godinu"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
